@@ -84,7 +84,7 @@
 		$err
 	);
 
-	our $VERSION = "2022.212.1";
+	our $VERSION = "2022.263.1";
 
 	our @EXPORT_OK = @EXPORT;
 
@@ -1863,7 +1863,7 @@ sub setMessage()
 		if ($self->{argv}{message_log} & SQL_SIMPLE_LOG_SYS)
 		{
 			require Sys::Syslog;
-			openlog($self->{argv}{message_syslog_service} || "SQL-Simple", "ndelay,pid", $self->{argv}{message_syslog_facility} || "local0");
+			openlog($self->{argv}{message_syslog_service} || "SQL-SimpleOps", "ndelay,pid", $self->{argv}{message_syslog_facility} || "local0");
 			syslog(
 				($SQL_SIMPLE_TABLE_OF_MSGS{$code}{T} eq "E") ? "error" :
 				($SQL_SIMPLE_TABLE_OF_MSGS{$code}{T} eq "S") ? "error" :
